pywws.Logger — pywws 13.06_r1023 documentation

### Navigation

- index
- modules |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »

# pywws.Logger

Common code for logging info and errors.

Functions

`ApplicationLogger`(verbose[, logfile]) |

`pywws.Logger.` `ApplicationLogger`(verbose, logfile=None)

### Navigation

- index
- modules |
- previous |
- pywws 13.06_r1023 documentation »
- Python programs and modules »